/* Header:      terrain.h */
/* Description: This file defines all the exportable functions for terrain.c */

/* constants */

#define LOD_FACTOR 20.0			/* factor to determine how detailed land is */
								/* heigher value = more detail (must be > 0 !) */

#define HEIGHT_FACTOR 0.05		/* number of world coords per height map intensity unit */
#define GRID_FACTOR 1.0			/* number of world coords per height map grid space */
#define TEX_SCALE 0.1			/* scale factor for detail texture */
#define WATER_TEX_SCALE 0.1		/* scale factor for water texture */

#define WATER_HEIGHT 5			/* upper limit of water in height map */
#define SHORE_HEIGHT 12			/* upper limit of shore in height map */
#define GRASS_HEIGHT 120		/* upper limit of grass in height map */
#define ROCK_HEIGHT 150			/* start of snow in height map */

#define WATER_COLOUR_R 0.48		/* colour of water areas */
#define WATER_COLOUR_G 0.6
#define WATER_COLOUR_B 0.72
#define GRASS_COLOUR_R 0.0		/* colour of grass areas */
#define GRASS_COLOUR_G 0.6
#define GRASS_COLOUR_B 0.0
#define SNOW_COLOUR_R 1.0		/* colour of snow areas */
#define SNOW_COLOUR_G 1.0
#define SNOW_COLOUR_B 1.0

#define AMBIENT_LIGHT_R 0.4		/* ambient light colour */
#define AMBIENT_LIGHT_G 0.4
#define AMBIENT_LIGHT_B 0.4
#define LIGHT_COLOUR_R 0.6		/* diffuse light colour */
#define LIGHT_COLOUR_G 0.6
#define LIGHT_COLOUR_B 0.6
#define LIGHT_ANGLE_X 0.5774	/* direction of light source */
#define LIGHT_ANGLE_Y -0.5774
#define LIGHT_ANGLE_Z 0.5774

/* variables */

extern unsigned char heightmap[257][257];
extern world_vector normalmap[256][256];
extern colour_rgb colourmap[257][257];
extern grid_vector distancemap[257][257];
extern terrain_cell lod5[8][8];
extern terrain_cell lod4[16][16];
extern terrain_cell lod3[32][32];
extern terrain_cell lod2[64][64];
extern terrain_cell lod1[128][128];
extern float lod_factor;
extern float tex_scale;

/* functions */

extern void position_to_grid_coord(world_vector pos, int* s, int* t);
extern float find_height_above_terrain(world_vector p);
extern void make_terrain(char filename[]);
extern void render_terrain();
